/**********************************************************************
 * Interface ExportHandler
 *  
 * Copyright (c) 2005-2012, German National Library/Deutsche Nationalbibliothek
 * Adickesallee 1, D-60322 Frankfurt am Main, Federal Republic of Germany 
 *
 * This program is free software.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * Kadir Karaca Kocer -- German National Library
 * 
 **********************************************************************/

package de.dnb.stm.handler.export;

import java.io.IOException;

import de.dnb.stm.processor.Processor;

/**
 * Interface defining a ExportHandler
 *
 * @since 10.04.2006
 * @author Alexander Slotta
 */
public interface ExportHandler {

	/**
	 * Returns the unique ID of this ExportHandler
	 * 
	 * @return Unique ID of this ExportHandler
	 * @author Kadir Karaca Kocer, German National Library
	 */
	public long getId();

    /**
     * @param newId The id to set.
     * @author Kadir Karaca Kocer, German National Library
     */
    public void setId(long newId);

	/**
	 * @return Human readable name of this ExportHandler
	 * @author Kadir Karaca Kocer, German National Library
	 */
	public String getName();
	
    /**
     * @param newName New name to set.
     * @author Kadir Karaca Kocer, German National Library
     */
    public void setName(String newName);
	
    /**
     * Saves the harvested records
     *
     * @param processor
     * @param item 
     * @param transactionId 
     * @return The number of records
     * @throws IOException 
     * @since 10.04.2006
     * @author Alexander Slotta
     * @throws ProcessorExportException 
     */
    public boolean save(Processor processor, Object item, String transactionId) throws IOException, ProcessorExportException; 
}
