/**********************************************************************
 * Interface ScheduleManager
 *  
 * Copyright (c) 2005-2012, German National Library/Deutsche Nationalbibliothek
 * Adickesallee 1, D-60322 Frankfurt am Main, Federal Republic of Germany 
 *
 * This program is free software.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * Kadir Karaca Kocer -- German National Library
 * 
 **********************************************************************/

package de.dnb.stm.manager;

import java.util.List;

import de.dnb.stm.handler.export.ExportHandlerDao;
import de.dnb.stm.processor.Processor;
import de.dnb.stm.task.Task;
import de.dnb.stm.task.TaskDao;
import de.dnb.stm.task.TaskStopRequestDao;

/**
 * 
 * @author Matthias Neubauer, German National Library
 */
public interface ScheduledManager 
{
	/**
	 * @throws InstantiationException
	 * @throws IllegalAccessException
	 * @throws SchedulerException
	 */
	public void scheduleTasks() throws InstantiationException, IllegalAccessException, SchedulerException;
	
	/**
	 * @param task
	 * @throws InstantiationException
	 * @throws IllegalAccessException
	 * @throws SchedulerException
	 */
	public void scheduleTask(Task task) throws InstantiationException, IllegalAccessException, SchedulerException;
	
	/**
	 * @param task
	 * @throws InstantiationException
	 * @throws IllegalAccessException
	 * @throws SchedulerException
	 */
	public void addTask(Task task) throws InstantiationException, IllegalAccessException, SchedulerException;
	
	/**
	 * @param task
	 * @throws InstantiationException
	 * @throws IllegalAccessException
	 * @throws SchedulerException
	 */
	public void removeTask(Task task) throws InstantiationException, IllegalAccessException, SchedulerException;
	
	/**
	 * @return The Task Data Access Object
	 */
	public TaskDao getTaskDao();
	
	/**
	 * @param newTaskDao
	 */
	public void setTaskDao(TaskDao newTaskDao);
	
	/**
	 * @return The TaskStop Data Access Object
	 */
	public TaskStopRequestDao getTaskStopRequestDao();
	
	/**
	 * @param newTaskStopRequestDao
	 */
	public void setTaskStopRequestDao(TaskStopRequestDao newTaskStopRequestDao);
	
	/**
	 * @return List of all tasks
	 */
	public List<Task> getTaskList();
	
	/**
	 * @param id
	 * @return The task with the given unique Id.
	 */
	public Task getTaskById(long id);
	
	/**
	 * @return The ExportHandler Data Access Object
	 */
	public ExportHandlerDao getExportHandlerDao();
	
	/**
	 * @param ehd ExportHandlerDao to set.
	 */
	public void setExportHandlerDao(ExportHandlerDao ehd);
	
	 /**
     * 
     * @return Processor for a Task
	 * @throws InstantiationException 
	 * @throws IllegalAccessException 
     */
    public Processor newProcessor() throws InstantiationException, IllegalAccessException;
}
