/**********************************************************************
 * Class TaskConstants
 *  
 * Copyright (c) 2005-2012, German National Library/Deutsche Nationalbibliothek
 * Adickesallee 1, D-60322 Frankfurt am Main, Federal Republic of Germany 
 *
 * This program is free software.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * Kadir Karaca Kocer -- German National Library
 * 
 **********************************************************************/

package de.dnb.stm.task;

/**
 * Some constant values.
 * 
 * @author Kadir Karaca Kocer -- German National Library
 */
public class TaskConstants
{

    /**
     * <p>Status for NOT YET defined status. <br />Default value {@value}.</p>
     */
    public final static int STATUS_NOT_DEFINED = -9999;
	
	/**
     * <p>The task status for in queue waiting tasks. <br />Default value {@value}.</p>
     */
    public final static int TASK_STATUS_WAITING = 9;
    
    /**
     * <p>The task status for running. <br />Default value {@value}.</p>
     */
    public final static int TASK_STATUS_RUNNING = 8;
    
    /**
     * <p>The task status for paused by user. <br />Default value {@value}.</p>
     */
    public final static int TASK_STATUS_PAUSED = 7;
   
    
    /**
     * <p>The task status for successfully finished processes. <br />Default value {@value}.</p>
     */
    public final static int TASK_STATUS_SUCCESSFULL = 0;
 
    /**
     * <p>The task status for interrupted. <br />Default value {@value}.</p>
     */
    public final static int TASK_STATUS_INTERRUPTED = -12;
    
    /**
     * <p>The task status for stopped by user. <br />Default value {@value}.</p>
     */
    public final static int TASK_STATUS_STOPPEDBYUSER = -13;

    /**
     * <p>The task status for cancelled. It happens when a one time task is
     * paused and the execution time arrives. <br />Default value {@value}.</p>
     */
    public final static int TASK_STATUS_TIMEDOUT = -14;
   
    /**
     * <p>The status for stopped on http error. <br />Default value  {@value}.</p>
     */
    public final static int TASK_STATUS_HTTP_ERROR = -41;
    
    /**
     * <p>The task status for server response NOT SC_OK (other than HTTP code 200).
     * <br />Default value {@value}.</p>
     */
    public final static int TASK_STATUS_RESPONSE_NOT_200 = -42;

    
    /**
     * <p>The task status for malformed OAI Response. <br />Default value {@value}.</p>
     */
    public final static int TASK_STATUS_INVALID_OAI_RESPONSE = -43;
    
    /**
     * <p>The task status for invalid metadata. <br />Default value {@value}.</p>
     */
    public final static int TASK_STATUS_METADATA_VALIDATION_ERROR = -44;
    
    /**
     * <p>The task status for IO Error.
     * <br />Default value {@value}.</p>
     */
    public final static int TASK_STATUS_IO_ERROR = -45;
    
    /**
     * <p>The task status for Error during export. <br />Default value {@value}.</p>
     */
    public final static int TASK_STATUS_EXPORT_ERROR = -46;
    
    /**
     * <p>The task status for Java Runtime Exception. <br />Default value {@value}.</p>
     */
    public final static int TASK_STATUS_RUNTIME_EXCEPTION = -51;
    
    
    /**
     * <p>The task status for Java Exception. <br />Default value {@value}.</p>
     */
    public final static int TASK_STATUS_GENERAL_EXCEPTION = -52;
    
    /**
     * <p>The task priority low. <br />Default value = "1"</p>
     */
    //public final static int TASK_PRIORITY_LOW = 1;

    /**
     * <p>The task priority normal. <br />Default value = "2"</p>
     */
    //public final static int TASK_PRIORITY_NORMAL = 2;

    /**
     * <p>The task priority high. <br />Default value = "3"</p>
     */
    //public final static int TASK_PRIORITY_HIGH = 3;

}
