/**********************************************************************
 * Interface TaskDao
 *  
 * Copyright (c) 2005-2012, German National Library/Deutsche Nationalbibliothek
 * Adickesallee 1, D-60322 Frankfurt am Main, Federal Republic of Germany 
 *
 * This program is free software.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * Kadir Karaca Kocer -- German National Library
 * 
 **********************************************************************/

package de.dnb.stm.task;

import java.util.List;

/** ******************************************************************
 * Interface defining how to process the Tasks.
 * 
 * @author Kadir Karaca Kocer, German National Library
 * @version 20120920
 **********************************************************************/

/* ******************************************************************
 * CHANGELOG:
 * 2008.11.20 Repository added  
 * Created on 07.08.2008 by Kadir Karaca Kocer, German National Library
 ******************************************************************/

public interface TaskDao {
	/**
	 * Saves the given task.
	 * 
	 * @param task OaiTask to save.
	 * @author Kadir Karaca Kocer, German National Library
	 */
	public void saveTask(Task task);
	
	/**
	 * Gets the task object with the given unique task id.
	 * 
	 * @param taskId Id to search for.
	 * @return OaiTask OaiTask which has this id.
	 * @author Kadir Karaca Kocer, German National Library
	 */
	public Task getTask(Long taskId);
	
	/**
	 * Deletes the given task.
	 * 
	 * @param task OaiTask to delete.
	 * @author Kadir Karaca Kocer, German National Library
	 */
	public void deleteTask(Task task);


	/**
	 * Returns the list of all tasks.
	 * 
	 * @return List of all Tasks.
	 * @author Kadir Karaca Kocer, German National Library
	 */
	public List<Task> getTaskList();
	    	
    /**
     * Removes tasks and requests which are older than given time limits (in minutes).
     * 
     * @param timeLimitTask Non-repeating tasks which are older than this limit will be removed from the list
     * @param timeLimitRequest Requests which are older than this limit will be removed from the list
     * @author Kadir Karaca Kocer, German National Library
     */
    public void garbageCollector(long timeLimitTask, long timeLimitRequest);
    
}
