/**********************************************************************
 * Interface TaskStopRequestDao
 *  
 * Copyright (c) 2012, German National Library/Deutsche Nationalbibliothek
 * Adickesallee 1, D-60322 Frankfurt am Main, Federal Republic of Germany 
 *
 * This program is free software.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * Kadir Karaca Kocer -- German National Library
 * 
 **********************************************************************/

package de.dnb.stm.task;

import java.util.List;

/** ******************************************************************
 * Interface defining how to process the TaskStopRequests
 * 
 * @author Matthias Neubauer, German National Library
 * @version 20120316
 **********************************************************************/

/* ******************************************************************
 * CHANGELOG:
 * Created on 16.03.2012 by Matthias Neubauer, German National Library
 ******************************************************************/

public interface TaskStopRequestDao {
	/**
	 * Saves the given taskStopRequest.
	 * 
	 * @param taskStopRequest taskStopRequest to save.
	 * @author Matthias Neubauer, German National Library
	 */
	public void saveTaskStopRequest(TaskStopRequest taskStopRequest);
	
	/**
	 * Gets the taskStopRequest object with the given unique id.
	 * 
	 * @param taskStopRequestId Id to search for.
	 * @return taskStopRequest taskStopRequest which has this id.
	 * @author Matthias Neubauer, German National Library
	 */
	public TaskStopRequest getTaskStopRequest(Long taskStopRequestId);
	
	/**
	 * Gets the taskStopRequest objects for the given unique task id.
	 * 
	 * @param taskId Id to search for.
	 * @return List<TaskStopRequest> List of requests that have this task id.
	 * @author Matthias Neubauer, German National Library
	 */
	public List<TaskStopRequest> findTaskStopRequestsByTaskId(Long taskId);
	
	
	/**
	 * Deletes the given taskStopRequest.
	 * 
	 * @param taskStopRequest TaskStopRequest to delete.
	 * @author Matthias Neubauer, German National Library
	 */
	public void deleteTaskStopRequest(TaskStopRequest taskStopRequest);


	/**
	 * Returns the list of all taskCancellationRequests.
	 * 
	 * @return List of all Tasks.
	 * @author Matthias Neubauer, German National Library
	 */
	public List<TaskStopRequest> getTaskStopRequestList();
    
}
